@@ -1,7 +1,7 @@
 use warnings;
 use strict;
 package Vimana::Command::Download;
-use base qw(App::CLI::Command);
+use parent qw(App::CLI::Command);
 use URI;
 use LWP::Simple qw();
 use File::Temp qw(tempdir);
