@@ -1,7 +1,7 @@
 package Vimana::Command::Installed;
 use warnings;
 use strict;
-use base qw(App::CLI::Command);
+use parent qw(App::CLI::Command);
 use YAML;
 use Vimana::Logger;
 use Vimana::Record;
