@@ -3,7 +3,12 @@ use strict;
 use warnings;
 use utf8;
 require LWP::UserAgent;
+use HTML::Entities;
+use Web::Scraper;
+use URI;
+
 my $last_pos;
+my $vimonline_search_url = "http://www.vim.org/scripts/script_search_results.php";
 
 sub parse_columns {
     my $c       = ${ $_[0] };
@@ -12,7 +17,8 @@ sub parse_columns {
         my $column_html = $1;
         while ( $column_html =~ m{<th.*?>(.*?)</th>}g ) {
             my $name = $1;
-            $name =~ s{</?.+?>}{}g;
+            $name = decode_entities( $name );
+            utf8::encode $name;
             push @$columns,lc $name;
         }
     }
@@ -40,6 +46,9 @@ ROW_END:
         while ( $tr =~ m{<td.*?>(.*?)</td>}gsi ) {
             my $td = $1;
             if( my ( $link, $text ) = ( $td =~ m{<a href="(.+?)">(.+?)</a>}i )  ) {
+                $text =~ s{&nbsp;}{ }g; # windows don't have 0xA0.
+                $text = decode_entities( $text );
+                utf8::encode $text;
                 ($script_id) = ( $link =~ /script_id=(\d+)/ );
                 $cols->{ $column_names->[ $col_index ] } = { text => $text, link => $link };
             }
@@ -69,21 +78,17 @@ sub fetch {
     my $class = shift;
     my %param = @_;
 
-    my $cache = Vimana->index->cache();
-    $cache->clear();
-
     my $uri = $class->build_search_uri( %param );
-    my $content = $cache->get( $uri );
+    my $content;
     unless( $content ) {
         my $ua = LWP::UserAgent->new;
+        $ua->env_proxy;
         my $response = $ua->get( $uri );
         # XXX: catch exception 
 
         die 'page query failed ' unless ($response->is_success);
 
         $content = $response->decoded_content;
-
-        $cache->set( "$uri" , $content );
     }
     return $class->parse( $content );
 }
@@ -105,16 +110,21 @@ sub build_search_uri {
     my %args = (
         keywords    => '',
         order_by    => 'rating',
-        #show_me     => 1000,
-        #result_ptr  => 0,
         %param ,
     );
 
-    my $uri = URI->new("http://www.vim.org/scripts/script_search_results.php");
+    my $uri = URI->new($vimonline_search_url);
     $uri->query_form( %args ); 
     return $uri;
 }
 
+sub all_vim_plugins {
+    my $class = shift;
+    my $scraper = scraper {
+        process '/html/body/table[2]/tr/td[3]/table/tr/td/table/tr/td[2]/b[3]', 'total' => 'TEXT';
+    };
+    return $scraper->scrape(URI->new($vimonline_search_url))->{total};
+}
 
 
 1;
